@@ -40,7 +40,7 @@ static char *display_property_str[] =
 void display_serialize(FILE *rsp, uint32_t did, uint64_t flags);
 CFStringRef display_uuid(uint32_t did);
 uint32_t display_id(CFStringRef uuid);
-CGRect display_bounds_constrained(uint32_t did);
+CGRect display_bounds_constrained(uint32_t did, bool ignore_external_bar);
 CGPoint display_center(uint32_t did);
 uint64_t display_space_id(uint32_t did);
 int display_space_count(uint32_t did);
