@@ -9,6 +9,26 @@ extern int g_connection;
 extern void *g_workspace_context;
 extern int g_layer_below_window_level;
 
+static void update_window_notifications(void)
+{
+    int window_count = 0;
+    uint32_t window_list[1024] = {0};
+
+    if (workspace_is_macos_sequoia()) {
+        // NOTE(koekeishiya): Subscribe to all windows because of window_destroyed (and ordered) notifications
+        table_for (struct window *window, g_window_manager.window, {
+            window_list[window_count++] = window->id;
+        })
+    } else {
+        // NOTE(koekeishiya): Subscribe to windows that have a feedback_border because of window_ordered notifications
+        table_for (struct window_node *node, g_window_manager.insert_feedback, {
+            window_list[window_count++] = node->window_order[0];
+        })
+    }
+
+    SLSRequestNotificationsForWindows(g_connection, window_list, window_count);
+}
+
 static void window_did_receive_focus(struct window_manager *wm, struct mouse_state *ms, struct window *window)
 {
     struct window *focused_window = window_manager_find_window(wm, wm->focused_window_id);
@@ -46,6 +66,8 @@ static void window_did_receive_focus(struct window_manager *wm, struct mouse_sta
     }
 }
 
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wunused-parameter"
 static EVENT_HANDLER(APPLICATION_LAUNCHED)
 {
     struct process *process = context;
@@ -154,29 +176,28 @@ static EVENT_HANDLER(APPLICATION_LAUNCHED)
             if (default_origin) sid = window_space(window->id);
 
             struct view *view = space_manager_find_view(&g_space_manager, sid);
-            if (view->layout == VIEW_FLOAT) goto next;
+            if (view->layout != VIEW_FLOAT) {
+                //
+                // @cleanup
+                //
+                // :AXBatching
+                //
+                // NOTE(koekeishiya): Batch all operations and mark the view as dirty so that we can perform a single flush,
+                // making sure that each window is only moved and resized a single time, when the final layout has been computed.
+                // This is necessary to make sure that we do not call the AX API for each modification to the tree.
+                //
 
-            //
-            // @cleanup
-            //
-            // :AXBatching
-            //
-            // NOTE(koekeishiya): Batch all operations and mark the view as dirty so that we can perform a single flush,
-            // making sure that each window is only moved and resized a single time, when the final layout has been computed.
-            // This is necessary to make sure that we do not call the AX API for each modification to the tree.
-            //
+                window_manager_adjust_layer(window, LAYER_BELOW);
+                view_add_window_node_with_insertion_point(view, window, prev_window_id);
+                window_manager_add_managed_window(&g_window_manager, window, view);
 
-            window_manager_adjust_layer(window, LAYER_BELOW);
-            view_add_window_node_with_insertion_point(view, window, prev_window_id);
-            window_manager_add_managed_window(&g_window_manager, window, view);
+                view_set_flag(view, VIEW_IS_DIRTY);
+                view_list[view_count++] = view;
 
-            view_set_flag(view, VIEW_IS_DIRTY);
-            view_list[view_count++] = view;
-
-            prev_window_id = window->id;
+                prev_window_id = window->id;
+            }
         }
 
-next:
         if (window_manager_is_window_eligible(window)) {
             event_signal_push(SIGNAL_WINDOW_CREATED, window);
         }
@@ -199,6 +220,10 @@ next:
         window_node_flush(view->root);
         view_clear_flag(view, VIEW_IS_DIRTY);
     }
+
+    if (workspace_is_macos_sequoia()) {
+        update_window_notifications();
+    }
 }
 
 static EVENT_HANDLER(APPLICATION_TERMINATED)
@@ -289,6 +314,10 @@ static EVENT_HANDLER(APPLICATION_TERMINATED)
         view_clear_flag(view, VIEW_IS_DIRTY);
     }
 
+    if (workspace_is_macos_sequoia()) {
+        update_window_notifications();
+    }
+
 out:
     process_destroy(process);
 }
@@ -524,6 +553,10 @@ static EVENT_HANDLER(WINDOW_CREATED)
     if (window_manager_is_window_eligible(window)) {
         event_signal_push(SIGNAL_WINDOW_CREATED, window);
     }
+
+    if (workspace_is_macos_sequoia()) {
+        update_window_notifications();
+    }
 }
 
 static EVENT_HANDLER(WINDOW_DESTROYED)
@@ -538,7 +571,7 @@ static EVENT_HANDLER(WINDOW_DESTROYED)
 
     struct view *view = window_manager_find_managed_window(&g_window_manager, window);
     if (view) {
-        space_manager_untile_window(&g_space_manager, view, window);
+        space_manager_untile_window(view, window);
         window_manager_remove_managed_window(&g_window_manager, window->id);
     }
 
@@ -551,6 +584,10 @@ static EVENT_HANDLER(WINDOW_DESTROYED)
     window_manager_remove_scratchpad_for_window(&g_window_manager, window, false);
     window_manager_remove_window(&g_window_manager, window->id);
     window_destroy(window);
+
+    if (workspace_is_macos_sequoia()) {
+        update_window_notifications();
+    }
 }
 
 static EVENT_HANDLER(WINDOW_FOCUSED)
@@ -606,21 +643,26 @@ static EVENT_HANDLER(WINDOW_MOVED)
 
     debug("%s: %s %d\n", __FUNCTION__, window->application->name, window->id);
     event_signal_push(SIGNAL_WINDOW_MOVED, window);
+    bool windowed_fullscreen = CGRectEqualToRect(window->windowed_frame, window->frame);
     window->frame.origin = new_origin;
 
-    if (!g_mouse_state.window || g_mouse_state.window != window) {
-        struct view *view = window_manager_find_managed_window(&g_window_manager, window);
-        if (view) {
-            struct window_node *node = view_find_window_node(view, window->id);
-            if (node && (AX_DIFF(node->area.x, new_origin.x) ||
-                         AX_DIFF(node->area.y, new_origin.y))
-                     &&
-               (!node->zoom || AX_DIFF(node->zoom->area.x, new_origin.x) ||
-                               AX_DIFF(node->zoom->area.y, new_origin.y))) {
-                if (space_is_visible(view->sid)) {
-                    window_node_flush(node);
-                } else {
-                    view_set_flag(view, VIEW_IS_DIRTY);
+    if (!windowed_fullscreen) {
+        window_clear_flag(window, WINDOW_WINDOWED);
+
+        if (!g_mouse_state.window || g_mouse_state.window != window) {
+            struct view *view = window_manager_find_managed_window(&g_window_manager, window);
+            if (view) {
+                struct window_node *node = view_find_window_node(view, window->id);
+                if (node && (AX_DIFF(node->area.x, new_origin.x) ||
+                             AX_DIFF(node->area.y, new_origin.y))
+                         &&
+                   (!node->zoom || AX_DIFF(node->zoom->area.x, new_origin.x) ||
+                                   AX_DIFF(node->zoom->area.y, new_origin.y))) {
+                    if (space_is_visible(view->sid)) {
+                        window_node_flush(node);
+                    } else {
+                        view_set_flag(view, VIEW_IS_DIRTY);
+                    }
                 }
             }
         }
@@ -661,12 +703,13 @@ static EVENT_HANDLER(WINDOW_RESIZED)
         window_clear_flag(window, WINDOW_FULLSCREEN);
     }
 
+    bool windowed_fullscreen = CGRectEqualToRect(window->windowed_frame, window->frame);
     window->frame = new_frame;
 
     if (!was_fullscreen && is_fullscreen) {
         struct view *view = window_manager_find_managed_window(&g_window_manager, window);
         if (view) {
-            space_manager_untile_window(&g_space_manager, view, window);
+            space_manager_untile_window(view, window);
             window_manager_remove_managed_window(&g_window_manager, window->id);
             window_manager_purify_window(&g_window_manager, window);
         }
@@ -682,23 +725,27 @@ static EVENT_HANDLER(WINDOW_RESIZED)
             g_mouse_state.window_frame.size = g_mouse_state.window->frame.size;
         }
 
-        if (!g_mouse_state.window || g_mouse_state.window != window) {
-            struct view *view = window_manager_find_managed_window(&g_window_manager, window);
-            if (view) {
-                struct window_node *node = view_find_window_node(view, window->id);
-                if (node && (AX_DIFF(node->area.x, new_frame.origin.x)   ||
-                             AX_DIFF(node->area.y, new_frame.origin.y)   ||
-                             AX_DIFF(node->area.w, new_frame.size.width) ||
-                             AX_DIFF(node->area.h, new_frame.size.height))
-                         &&
-                   (!node->zoom || AX_DIFF(node->zoom->area.x, new_frame.origin.x)   ||
-                                   AX_DIFF(node->zoom->area.y, new_frame.origin.y)   ||
-                                   AX_DIFF(node->zoom->area.w, new_frame.size.width) ||
-                                   AX_DIFF(node->zoom->area.h, new_frame.size.height))) {
-                    if (space_is_visible(view->sid)) {
-                        window_node_flush(node);
-                    } else {
-                        view_set_flag(view, VIEW_IS_DIRTY);
+        if (!windowed_fullscreen) {
+            window_clear_flag(window, WINDOW_WINDOWED);
+
+            if (!g_mouse_state.window || g_mouse_state.window != window) {
+                struct view *view = window_manager_find_managed_window(&g_window_manager, window);
+                if (view) {
+                    struct window_node *node = view_find_window_node(view, window->id);
+                    if (node && (AX_DIFF(node->area.x, new_frame.origin.x)   ||
+                                 AX_DIFF(node->area.y, new_frame.origin.y)   ||
+                                 AX_DIFF(node->area.w, new_frame.size.width) ||
+                                 AX_DIFF(node->area.h, new_frame.size.height))
+                             &&
+                       (!node->zoom || AX_DIFF(node->zoom->area.x, new_frame.origin.x)   ||
+                                       AX_DIFF(node->zoom->area.y, new_frame.origin.y)   ||
+                                       AX_DIFF(node->zoom->area.w, new_frame.size.width) ||
+                                       AX_DIFF(node->zoom->area.h, new_frame.size.height))) {
+                        if (space_is_visible(view->sid)) {
+                            window_node_flush(node);
+                        } else {
+                            view_set_flag(view, VIEW_IS_DIRTY);
+                        }
                     }
                 }
             }
@@ -724,7 +771,7 @@ static EVENT_HANDLER(WINDOW_MINIMIZED)
 
     struct view *view = window_manager_find_managed_window(&g_window_manager, window);
     if (view) {
-        space_manager_untile_window(&g_space_manager, view, window);
+        space_manager_untile_window(view, window);
         window_manager_remove_managed_window(&g_window_manager, window->id);
         window_manager_purify_window(&g_window_manager, window);
     }
@@ -788,6 +835,22 @@ static EVENT_HANDLER(SLS_WINDOW_ORDERED)
     if (node) SLSOrderWindow(g_connection, node->feedback_window.id, 1, node->window_order[0]);
 }
 
+static EVENT_HANDLER(SLS_WINDOW_DESTROYED)
+{
+    uint32_t wid = (uint64_t)(intptr_t) context;
+    debug("%s: %d\n", __FUNCTION__, wid);
+
+    struct window *window = window_manager_find_window(&g_window_manager, wid);
+    if (!window) return;
+
+    if (!__sync_bool_compare_and_swap(&window->id_ptr, &window->id, &window->id)) {
+        debug("%s: %d has been marked invalid by the system, ignoring event..\n", __FUNCTION__, wid);
+        return;
+    }
+
+    EVENT_HANDLER_WINDOW_DESTROYED(window, 0);
+}
+
 static EVENT_HANDLER(SLS_SPACE_CREATED)
 {
     uint64_t sid = (uint64_t)(intptr_t) context;
@@ -1008,22 +1071,22 @@ static EVENT_HANDLER(MOUSE_UP)
             enum mouse_drop_action drop_action = mouse_determine_drop_action(&g_mouse_state, a_node, window, point);
             switch (drop_action) {
             case MOUSE_DROP_ACTION_STACK: {
-                mouse_drop_action_stack(&g_space_manager, &g_window_manager, src_view, g_mouse_state.window, dst_view, window);
+                mouse_drop_action_stack(&g_window_manager, src_view, g_mouse_state.window, dst_view, window);
             } break;
             case MOUSE_DROP_ACTION_SWAP: {
                 mouse_drop_action_swap(&g_window_manager, src_view, a_node, g_mouse_state.window, dst_view, b_node, window);
             } break;
             case MOUSE_DROP_ACTION_WARP_TOP: {
-                mouse_drop_action_warp(&g_space_manager, &g_window_manager, src_view, a_node, g_mouse_state.window, dst_view, b_node, window, SPLIT_X, CHILD_FIRST);
+                mouse_drop_action_warp(&g_window_manager, src_view, a_node, g_mouse_state.window, dst_view, b_node, window, SPLIT_X, CHILD_FIRST);
             } break;
             case MOUSE_DROP_ACTION_WARP_RIGHT: {
-                mouse_drop_action_warp(&g_space_manager, &g_window_manager, src_view, a_node, g_mouse_state.window, dst_view, b_node, window, SPLIT_Y, CHILD_SECOND);
+                mouse_drop_action_warp(&g_window_manager, src_view, a_node, g_mouse_state.window, dst_view, b_node, window, SPLIT_Y, CHILD_SECOND);
             } break;
             case MOUSE_DROP_ACTION_WARP_BOTTOM: {
-                mouse_drop_action_warp(&g_space_manager, &g_window_manager, src_view, a_node, g_mouse_state.window, dst_view, b_node, window, SPLIT_X, CHILD_SECOND);
+                mouse_drop_action_warp(&g_window_manager, src_view, a_node, g_mouse_state.window, dst_view, b_node, window, SPLIT_X, CHILD_SECOND);
             } break;
             case MOUSE_DROP_ACTION_WARP_LEFT: {
-                mouse_drop_action_warp(&g_space_manager, &g_window_manager, src_view, a_node, g_mouse_state.window, dst_view, b_node, window, SPLIT_Y, CHILD_FIRST);
+                mouse_drop_action_warp(&g_window_manager, src_view, a_node, g_mouse_state.window, dst_view, b_node, window, SPLIT_Y, CHILD_FIRST);
             } break;
             case MOUSE_DROP_ACTION_NONE: {
                 /* silence compiler warning.. */
@@ -1066,7 +1129,7 @@ static EVENT_HANDLER(MOUSE_DRAGGED)
 
         uint32_t did = display_manager_point_display_id(new_point);
         if (did) {
-            CGRect bounds = display_bounds_constrained(did);
+            CGRect bounds = display_bounds_constrained(did, false);
             if (new_point.y < bounds.origin.y) new_point.y = bounds.origin.y;
         }
 
@@ -1241,10 +1304,10 @@ static EVENT_HANDLER(MOUSE_MOVED)
         uint32_t cursor_did = display_manager_point_display_id(point);
         if (g_display_manager.current_display_id == cursor_did) goto out;
 
-        CGRect bounds = display_bounds_constrained(cursor_did);
+        CGRect bounds = display_bounds_constrained(cursor_did, false);
         if (!cgrect_contains_point(bounds, point)) goto out;
 
-        uint32_t wid = display_manager_focus_display_with_point(cursor_did, point, false);
+        uint32_t wid = display_manager_focus_display_with_point(point, false);
         g_mouse_state.ffm_window_id = wid;
     }
 
@@ -1349,7 +1412,10 @@ static EVENT_HANDLER(DOCK_DID_RESTART)
 {
     debug("%s:\n", __FUNCTION__);
 
-    if (workspace_is_macos_monterey() || workspace_is_macos_ventura() || workspace_is_macos_sonoma()) {
+    if (workspace_is_macos_monterey() ||
+        workspace_is_macos_ventura() ||
+        workspace_is_macos_sonoma() ||
+        workspace_is_macos_sequoia()) {
         mission_control_unobserve();
         mission_control_observe();
     }
@@ -1443,6 +1509,7 @@ static EVENT_HANDLER(DAEMON_MESSAGE)
 
     socket_close(param1);
 }
+#pragma clang diagnostic pop
 
 static void *event_loop_run(void *context)
 {
