@@ -58,6 +58,7 @@ extern CGError SLSOrderWindow(int cid, uint32_t wid, int order, uint32_t rel_wid
 extern void SLSManagedDisplaySetCurrentSpace(int cid, CFStringRef display_ref, uint64_t sid);
 extern uint64_t SLSManagedDisplayGetCurrentSpace(int cid, CFStringRef display_ref);
 extern CFStringRef SLSCopyManagedDisplayForSpace(int cid, uint64_t sid);
+extern void SLSMoveWindowsToManagedSpace(int cid, CFArrayRef window_list, uint64_t sid);
 extern void SLSShowSpaces(int cid, CFArrayRef space_list);
 extern void SLSHideSpaces(int cid, CFArrayRef space_list);
 extern CFTypeRef SLSTransactionCreate(int cid);
@@ -85,6 +86,7 @@ static uint64_t remove_space_fp;
 static uint64_t move_space_fp;
 static uint64_t set_front_window_fp;
 static uint64_t animation_time_addr;
+static bool macOSSequoia;
 
 static pthread_t daemon_thread;
 static int daemon_sockfd;
@@ -229,9 +231,12 @@ static bool verify_os_version(NSOperatingSystemVersion os_version)
         return true; // Ventura 13.0
     } else if (os_version.majorVersion == 14) {
         return true; // Sonoma 14.0
+    } else if (os_version.majorVersion == 15) {
+        macOSSequoia = true;
+        return true; // Sequoia 15.0
     }
 
-    NSLog(@"[yabai-sa] spaces functionality is only supported on macOS Big Sur 11.0.0+, Monterey 12.0.0+, Ventura 13.0.0+, and Sonoma 14.0.0+");
+    NSLog(@"[yabai-sa] spaces functionality is only supported on macOS Big Sur 11.0.0+, Monterey 12.0.0+, Ventura 13.0.0+, Sonoma 14.0.0+, and Sequoia 15.0");
 #elif __arm64__
     if (os_version.majorVersion == 12) {
         return true; // Monterey 12.0
@@ -239,9 +244,12 @@ static bool verify_os_version(NSOperatingSystemVersion os_version)
         return true; // Ventura 13.0
     } else if (os_version.majorVersion == 14) {
         return true; // Sonoma 14.0
+    } else if (os_version.majorVersion == 15) {
+        macOSSequoia = true;
+        return true; // Sequoia 15.0
     }
 
-    NSLog(@"[yabai-sa] spaces functionality is only supported on macOS Monterey 12.0.0+, and Ventura 13.0.0+, and Sonoma 14.0.0+");
+    NSLog(@"[yabai-sa] spaces functionality is only supported on macOS Monterey 12.0.0+, and Ventura 13.0.0+, Sonoma 14.0.0+, and Sequoia 15.0");
 #endif
 
     return false;
@@ -535,7 +543,9 @@ static void do_space_create(char *message)
 
     CFStringRef __block display_uuid = SLSCopyManagedDisplayForSpace(SLSMainConnectionID(), space_id);
     dispatch_sync(dispatch_get_main_queue(), ^{
-        id new_space = [[objc_getClass("Dock.ManagedSpace") alloc] init];
+        id new_space = macOSSequoia
+                     ? [[objc_getClass("ManagedSpace") alloc] init]
+                     : [[objc_getClass("Dock.ManagedSpace") alloc] init];
         id display_space = display_space_for_display_uuid(display_uuid);
         asm__call_add_space(new_space, display_space, add_space_fp);
         CFRelease(display_uuid);
@@ -551,7 +561,9 @@ static void do_space_focus(char *message)
 
     if (dest_space_id) {
         CFStringRef dest_display = SLSCopyManagedDisplayForSpace(SLSMainConnectionID(), dest_space_id);
-        id source_space = ((id (*)(id, SEL, CFStringRef)) objc_msgSend)(dock_spaces, @selector(currentSpaceforDisplayUUID:), dest_display);
+        id source_space = macOSSequoia
+                        ? ((id (*)(id, SEL, CFStringRef)) objc_msgSend)(dock_spaces, @selector(currentSpaceForDisplayUUID:), dest_display)
+                        : ((id (*)(id, SEL, CFStringRef)) objc_msgSend)(dock_spaces, @selector(currentSpaceforDisplayUUID:), dest_display);
         uint64_t source_space_id = get_space_id(source_space);
 
         if (source_space_id != dest_space_id) {
@@ -869,6 +881,49 @@ static void do_window_order_in(char *message)
     CFRelease(transaction);
 }
 
+static inline CFArrayRef cfarray_of_cfnumbers(void *values, size_t size, int count, CFNumberType type)
+{
+    CFNumberRef temp[count];
+
+    for (int i = 0; i < count; ++i) {
+        temp[i] = CFNumberCreate(NULL, type, ((char *)values) + (size * i));
+    }
+
+    CFArrayRef result = CFArrayCreate(NULL, (const void **)temp, count, &kCFTypeArrayCallBacks);
+
+    for (int i = 0; i < count; ++i) {
+        CFRelease(temp[i]);
+    }
+
+    return result;
+}
+
+static void do_window_list_move_to_space(char *message)
+{
+    uint64_t sid;
+    unpack(sid);
+
+    int count = 0;
+    unpack(count);
+
+    CFArrayRef window_list_ref = cfarray_of_cfnumbers((uint32_t*)message, sizeof(uint32_t), count, kCFNumberSInt32Type);
+    SLSMoveWindowsToManagedSpace(SLSMainConnectionID(), window_list_ref, sid);
+    CFRelease(window_list_ref);
+}
+
+static void do_window_move_to_space(char *message)
+{
+    uint64_t sid;
+    unpack(sid);
+
+    uint32_t wid;
+    unpack(wid);
+
+    CFArrayRef window_list_ref = cfarray_of_cfnumbers(&wid, sizeof(uint32_t), 1, kCFNumberSInt32Type);
+    SLSMoveWindowsToManagedSpace(SLSMainConnectionID(), window_list_ref, sid);
+    CFRelease(window_list_ref);
+}
+
 static void do_handshake(int sockfd)
 {
     uint32_t attrib = 0;
@@ -949,6 +1004,12 @@ static void handle_message(int sockfd, char *message)
     case SA_OPCODE_WINDOW_ORDER_IN: {
         do_window_order_in(message);
     } break;
+    case SA_OPCODE_WINDOW_LIST_TO_SPACE: {
+        do_window_list_move_to_space(message);
+    } break;
+    case SA_OPCODE_WINDOW_TO_SPACE: {
+        do_window_move_to_space(message);
+    } break;
     }
 }
 
