@@ -5,7 +5,9 @@
     __asm__("movq %0, %%rdi;""movq %1, %%rsi;""movq %2, %%rdx;""movq %3, %%r13;""callq *%4;" : :"r"(v0), "r"(v1), "r"(v2), "r"(v3), "r"(func) :"%rdi", "%rsi", "%rdx", "%r13");
 
 uint64_t get_dock_spaces_offset(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return 0xA0000;
+    } else if (os_version.majorVersion == 14) {
         return os_version.minorVersion > 0 ? 0xD5000 : 0x140000;
     } else if (os_version.majorVersion == 13) {
         return 0x140000;
@@ -19,7 +21,9 @@ uint64_t get_dock_spaces_offset(NSOperatingSystemVersion os_version) {
 }
 
 uint64_t get_dppm_offset(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return 0x13b000;
+    } else if (os_version.majorVersion == 14) {
         return os_version.minorVersion > 0 ? 0x12ce00 : 0x8000;
     } else if (os_version.majorVersion == 13) {
         return 0x8000;
@@ -33,7 +37,9 @@ uint64_t get_dppm_offset(NSOperatingSystemVersion os_version) {
 }
 
 uint64_t get_fix_animation_offset(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return 0x280000;
+    } else if (os_version.majorVersion == 14) {
         return os_version.minorVersion > 0 ? 0x1f0000 : 0x210000;
     } else if (os_version.majorVersion == 13) {
         return 0x210000;
@@ -47,7 +53,9 @@ uint64_t get_fix_animation_offset(NSOperatingSystemVersion os_version) {
 }
 
 uint64_t get_add_space_offset(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return 0x280000;
+    } else if (os_version.majorVersion == 14) {
         return os_version.minorVersion > 0 ? 0x1f0000 : 0x217000;
     } else if (os_version.majorVersion == 13) {
         return 0x213000;
@@ -61,7 +69,9 @@ uint64_t get_add_space_offset(NSOperatingSystemVersion os_version) {
 }
 
 uint64_t get_remove_space_offset(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return 0x1e0000;
+    } else if (os_version.majorVersion == 14) {
         return os_version.minorVersion > 0 ? 0x2B0000 : 0x2D0000;
     } else if (os_version.majorVersion == 13) {
         return 0x2C0000;
@@ -75,7 +85,9 @@ uint64_t get_remove_space_offset(NSOperatingSystemVersion os_version) {
 }
 
 uint64_t get_move_space_offset(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return 0x1e0000;
+    } else if (os_version.majorVersion == 14) {
         return os_version.minorVersion > 0 ? 0x2A0000 : 0x2C0000;
     } else if (os_version.majorVersion == 13) {
         return 0x2B0000;
@@ -89,7 +101,9 @@ uint64_t get_move_space_offset(NSOperatingSystemVersion os_version) {
 }
 
 uint64_t get_set_front_window_offset(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return 0x3d000;
+    } else if (os_version.majorVersion == 14) {
         return os_version.minorVersion > 0 ? 0x4a000 : 0x51BBE;
     } else if (os_version.majorVersion == 13) {
         return 0x52000;
@@ -103,9 +117,11 @@ uint64_t get_set_front_window_offset(NSOperatingSystemVersion os_version) {
 }
 
 const char *get_dock_spaces_pattern(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return "?? ?? ?? 00 48 8B 38 48 8B 35 ?? ?? ?? 00 89 DA 41 FF D5 48 89 C7 E8 ?? ?? ?? 00 49 89 C7 48 8B 35 ?? ?? ?? 00 48 89";
+    } else if (os_version.majorVersion == 14) {
         if (os_version.minorVersion > 0) {
-            return "?? ?? ?? 00 48 8B 38 48 8B 35 ?? ?? 2F 00 89 DA 41 FF D5 48 89 C7 E8 ?? ?? 22 00 49 89 C7 48 8B 35 ?? ?? 2F 00 48 89";
+            return "?? ?? ?? 00 48 8B 38 48 8B 35 ?? ?? ?? 00 89 DA 41 FF D5 48 89 C7 E8 ?? ?? ?? 00 49 89 C7 48 8B 35 ?? ?? ?? 00 48 89";
         }
         return "?? ?? ?? 00 49 8B 3E 48 8B 35 A0 DD 2B 00 44 89 A5 78 FE FF FF 44 89 E2 49 89 DC FF D3 48 89 C7 E8 C5 66 1E 00 48 89 85 F8 FD FF FF 48 8B 3D FB 19 2C 00 E8 0A 66 1E 00 48 8B 1D 2F EA 2B 00 48 89 C7 48 89 DE 31 D2 41 FF D4 48 89 85 38 FE FF FF 49";
     } else if (os_version.majorVersion == 13) {
@@ -120,7 +136,9 @@ const char *get_dock_spaces_pattern(NSOperatingSystemVersion os_version) {
 }
 
 const char *get_dppm_pattern(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return "?? ?? ?? 00 31 FF 5D E9 ?? ?? 1F 00";
+    } else if (os_version.majorVersion == 14) {
         if (os_version.minorVersion > 0) {
             return "?? ?? ?? 00 31 FF 5D E9 ?? ?? 1C 00";
         }
@@ -138,7 +156,9 @@ const char *get_dppm_pattern(NSOperatingSystemVersion os_version) {
 
 
 const char *get_fix_animation_pattern(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return "F2 0F 10 05 ?? ?? ?? 00 48 8B ?? ?? 48 89 DE";
+    } else if (os_version.majorVersion == 14) {
         return "F2 0F 10 05 ?? ?? ?? 00 4C 89 ?? 48 89 DE";
     } else if (os_version.majorVersion == 13) {
         return "F2 0F 10 05 ?? ?? ?? 00 4C 89 ?? 48 8B 75 ?? ?? 89 ?? 44 8B 85 ?? FF FF FF 4C 8B 8D ?? FF FF FF 4C 8B 6D ?? 50 56 6A 01 ?? ?? ?? ?? ?? ??";
@@ -152,7 +172,9 @@ const char *get_fix_animation_pattern(NSOperatingSystemVersion os_version) {
 }
 
 const char *get_add_space_pattern(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return "55 48 89 E5 41 57 41 56 41 55 41 54 53 48 83 EC 28 48 BA 01 00 00 00 00 00 00 40 48 B9 F8 FF FF FF FF FF FF 00 49 8D 45 28 49 8B 5D 28 41 80 7D 38 01 48 89 7D C0 4C 89 6D B0 75 49 49 89 FC 48 85 D3 0F 84 22 01 00 00 49 89 DE 49 21 CE F6 C3 01";
+    } else if (os_version.majorVersion == 14) {
         if (os_version.minorVersion >= 4) {
             return "55 48 89 E5 41 57 41 56 41 55 41 54 53 48 83 EC 28 48 89 7D C8 49 BE 01 00 00 00 00 00 00 40 49 BC F8 FF FF FF FF FF FF 00 49 8D 45 28 48 89 45 D0 4D 8B 7D 28 4C 89 6D B8 41 80 7D 38 01 75 15 4D 85 F7 0F 85 4D 03 00 00 4D 21 E7 49 8B 5F 10 E9 96 01 00 00 4D 85 F7 0F 85 68 03 00 00 4C 89 F8 4C 21 E0 48 8B 58 10 4C 89 FF E8 ?? ?? 10 00 48 85 DB 0F 84 24 01 00 00 49 89 DC 49 FF CC 0F 80 67 03 00 00 49 BE 03 00 00 00 00 00";
         }
@@ -172,7 +194,9 @@ const char *get_add_space_pattern(NSOperatingSystemVersion os_version) {
 }
 
 const char *get_remove_space_pattern(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return "55 48 89 E5 41 57 41 56 41 55 41 54 53 48 83 EC 68 49 89 CC 49 89 D6 49 89 F5 49 89 FF 48 BB F8 FF FF FF FF FF FF 00 E8 ?? ?? 09 00 48 89 C1 48 B8 01 00 00 00 00 00 00 40 48 21 CB 48 85 C1 0F 85 74 02 00 00 48 8B 43 10 48 83 F8 02 0F 8C E8 01 00";
+    } else if (os_version.majorVersion == 14) {
         return "55 48 89 E5 41 57 41 56 41 55 41 54 53 48 83 EC 68 48 89 4D ?? 49 89 D7 49 89 F5 49 89 FC 48 BB F8 FF FF FF FF FF FF 00 E8 ?? ?? ?? FF 49 89 C6 48 B8 01 00 00 00 00 00 00 40 4C 21 F3 49 85 C6 0F 85 ?? 02 00 00 48 8B 43 10 48 83 F8 02 0F 8C ?? 02 00 00 4C 89 6D ?? 4C 89 75 A0 48 8D 05 ?? ?? ?? 00 48 8B 00 49 8B 1C 04 4D 8B 74 04 08 48 8D 05 ?? ?? ?? 00 48 8B 38 48 8B 35 ?? ?? ??";
     } else if (os_version.majorVersion == 13) {
         return "55 48 89 E5 41 57 41 56 41 55 41 54 53 48 83 EC 68 48 89 4D 88 49 89 D6 49 89 F5 49 89 FF E8 ?? ?? F4 FF 48 89 C3 48 B8 01 00 00 00 00 00 00 40 48 85 C3 0F 85 ?? 04 00 00 48 B8 F8 FF FF FF FF FF FF 00 48 21 D8 48 8B 40 10 48 83 F8 02 0F 8C ?? 02 00 00 4C 89 6D 90 48 89 5D A8 48 8D 05 ?? ?? 13 00 48 8B 00 4C 89 F3 4D 8B 34 07 4D 8B 64 07 08 48 8D 05 ?? ?? ?? 00 48 8B 38 48 8B 35 ?? ?? 12 00 4C 89 7D A0 4C 89";
@@ -192,7 +216,9 @@ const char *get_remove_space_pattern(NSOperatingSystemVersion os_version) {
 }
 
 const char *get_move_space_pattern(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
+    if (os_version.majorVersion == 15) {
+        return "55 48 89 E5 41 57 41 56 41 55 41 54 53 48 83 EC 38 4C 89 E9 41 89 D5 49 89 F7 49 89 FC 48 8B 05 ?? ?? 25 00 4C 8B 34 07 4C 89 F7 48 89 4D A0 48 89 CE E8 65 BE FF FF 48 89 55 D0 48 85 C0 74 4C 48 89 C3 48 8D 05 ?? ?? 26 00 48 8B 38 48 8B 35 ?? ?? 23 00 E8 ?? ?? 14 00 84 C0 74 37 4C 8B 65";
+    } else if (os_version.majorVersion == 14) {
         return "55 48 89 E5 41 57 41 56 41 55 41 54 53 48 83 EC 48 4C 89 E9 41 89 D5 49 89 ?? 49 89 FF ?? 8D ?? ?? ?? ?? 00 ?? 8B ?? ?? 8B ?? 07 ?? 89 ?? 48 89 4D A0 48 89 CE E8 ?? ?? 00 00 48 89 55 D0 48 89 45 C8 48 85 C0 74 3F 48 8D 05 ?? ?? ?? 00 80 38 01 75 ?? ?? 8B ?? D0 ?? 89 ?? 49 83 C5 28 4C 8B 7D C8 4C 89 FF E8 ?? ?? ?? FF 48 89 C7 FF 15 ?? ?? 0C 00";
     } else if (os_version.majorVersion == 13) {
         return "55 48 89 E5 41 57 41 56 41 55 41 54 53 48 83 EC 48 4C 89 E9 41 89 D5 49 89 F6 49 89 FF 48 8D 1D ?? ?? 14 00 48 8B 03 4C 8B 24 07 4C 89 E7 48 89 4D A0 48 89 CE E8 ?? ?? 00 00 48 89 55 D0 48 89 45 C8 48 85 C0 74 3F 48 8D 05 ?? ?? 15 00 80 38 01 75 3A 4C 8B 65 D0 4D 89 E5 49 83 C5 28 4C 8B 7D C8 4C 89 FF E8 ?? ?? F5 FF 48 89 C7 FF 15 ?? ?? 0C 00";
@@ -212,8 +238,10 @@ const char *get_move_space_pattern(NSOperatingSystemVersion os_version) {
 }
 
 const char *get_set_front_window_pattern(NSOperatingSystemVersion os_version) {
-    if (os_version.majorVersion == 14) {
-        return "55 48 89 E5 41 57 41 56 41 54 53 48 83 EC 60 48 8B 05 ?? ?? ?? 00 48 8B 00 48 89 45 D8 85 F6 0F 84 01 02 00 00 89 F3 49 89 FE 49 89 FF 49 C1 EF 20 48 8D 75 AF C6 06 00 E8 ?? ?? 02 00 48 8B 3D ?? ?? ?? 00 BE 01 00 00 00 E8 ?? ?? ?? 00 84 C0 74 5A 44 0F B6 65 AF 4C 8D 45 B0 41 C7 00 00 04 00 04 45 89 70 04 66 B8 00 04 66 41 89 40 08 45 89 78 0A 66 41 89 40 0E 41 89 58 10 66 41 89 40";
+    if (os_version.majorVersion == 15) {
+        return "55 48 89 E5 41 57 41 56 41 54 53 48 83 EC 60 48 8B 05 ?? ?? ?? 00 48 8B 00 48 89 45 D8 85 F6 0F 84 ?? 02 00 00 89 F3 49 89 FE 49 89 FC 49 C1 ?? 20 ?? 8D ?? AF 41 C6 07 00 4C 89 FE E8 ?? ?? 06 00 48 8B";
+    } else if (os_version.majorVersion == 14) {
+        return "55 48 89 E5 41 57 41 56 41 54 53 48 83 EC 60 48 8B 05 ?? ?? ?? 00 48 8B 00 48 89 45 D8 85 F6 0F 84 ?? 02 00 00 89 F3 49 89 FE 49 89 FF 49 C1 EF 20 48 8D 75 AF C6 06 00 E8 ?? ?? 02 00 48 8B 3D ?? ?? ?? 00 BE 01 00 00 00 E8 ?? ?? ?? 00 84 C0 74 5A 44 0F B6 65 AF 4C 8D 45 B0 41 C7 00 00 04 00 04 45 89 70 04 66 B8 00 04 66 41 89 40 08 45 89 78 0A 66 41 89 40 0E 41 89 58 10 66 41 89 40";
     } else if (os_version.majorVersion == 13) {
         return "55 48 89 E5 41 57 41 56 41 55 41 54 53 48 83 EC 58 48 8B 05 ?? ?? ?? 00 48 8B 00 48 89 45 D0 85 F6 0F 84 00 02 00 00 41 89 F6 49 89 FD 49 89 FF 49 C1 EF 20 48 8D 75 AF C6 06 00 E8 ?? ?? 02 00 48 8B 3D ?? ?? ?? 00 BE 01 00 00 00 E8 ?? ?? 2C 00 84 C0 74 59 0F B6 5D AF 4C 8D 45 B0 41 C7 00 00 04 00 04 45 89 68 04 66 B8 00 04 66 41 89 40 08 45 89 78 0A 66 41 89 40 0E 45 89 70 10 66 41";
     } else if (os_version.majorVersion == 12) {
