@@ -127,7 +127,7 @@ void space_manager_mark_view_invalid(struct space_manager *sm,  uint64_t sid)
     view_clear_flag(view, VIEW_IS_VALID);
 }
 
-void space_manager_untile_window(struct space_manager *sm, struct view *view, struct window *window)
+void space_manager_untile_window(struct view *view, struct window *window)
 {
     if (view->layout == VIEW_FLOAT) return;
 
@@ -259,137 +259,88 @@ void space_manager_toggle_show_desktop(uint64_t sid)
 void space_manager_set_layout_for_all_spaces(struct space_manager *sm, enum view_type layout)
 {
     sm->layout = layout;
-    for (int i = 0; i < sm->view.capacity; ++i) {
-        struct bucket *bucket = sm->view.buckets[i];
-        while (bucket) {
-            if (bucket->value) {
-                struct view *view = bucket->value;
-                if (!view_check_flag(view, VIEW_LAYOUT)) {
-                    if (space_is_user(view->sid)) {
-                        view->layout = layout;
-                        view_clear(view);
+    table_for (struct view *view, sm->view, {
+        if (!view_check_flag(view, VIEW_LAYOUT)) {
+            if (space_is_user(view->sid)) {
+                view->layout = layout;
+                view_clear(view);
 
-                        if (view->layout != VIEW_FLOAT) {
-                            window_manager_validate_and_check_for_windows_on_space(sm, &g_window_manager, view->sid);
-                        }
-                    }
+                if (view->layout != VIEW_FLOAT) {
+                    window_manager_validate_and_check_for_windows_on_space(sm, &g_window_manager, view->sid);
                 }
             }
-            bucket = bucket->next;
         }
-    }
+    })
 }
 
 void space_manager_set_window_gap_for_all_spaces(struct space_manager *sm, int window_gap)
 {
     sm->window_gap = window_gap;
-    for (int i = 0; i < sm->view.capacity; ++i) {
-        struct bucket *bucket = sm->view.buckets[i];
-        while (bucket) {
-            if (bucket->value) {
-                struct view *view = bucket->value;
-                if (!view_check_flag(view, VIEW_WINDOW_GAP)) {
-                    view->window_gap = window_gap;
-                    view_update(view);
-                    view_flush(view);
-                }
-            }
-            bucket = bucket->next;
+    table_for (struct view *view, sm->view, {
+        if (!view_check_flag(view, VIEW_WINDOW_GAP)) {
+            view->window_gap = window_gap;
+            view_update(view);
+            view_flush(view);
         }
-    }
+    })
 }
 
 void space_manager_set_top_padding_for_all_spaces(struct space_manager *sm, int top_padding)
 {
     sm->top_padding = top_padding;
-    for (int i = 0; i < sm->view.capacity; ++i) {
-        struct bucket *bucket = sm->view.buckets[i];
-        while (bucket) {
-            if (bucket->value) {
-                struct view *view = bucket->value;
-                if (!view_check_flag(view, VIEW_TOP_PADDING)) {
-                    view->top_padding = top_padding;
-                    view_update(view);
-                    view_flush(view);
-                }
-            }
-            bucket = bucket->next;
+    table_for (struct view *view, sm->view, {
+        if (!view_check_flag(view, VIEW_TOP_PADDING)) {
+            view->top_padding = top_padding;
+            view_update(view);
+            view_flush(view);
         }
-    }
+    })
 }
 
 void space_manager_set_bottom_padding_for_all_spaces(struct space_manager *sm, int bottom_padding)
 {
     sm->bottom_padding = bottom_padding;
-    for (int i = 0; i < sm->view.capacity; ++i) {
-        struct bucket *bucket = sm->view.buckets[i];
-        while (bucket) {
-            if (bucket->value) {
-                struct view *view = bucket->value;
-                if (!view_check_flag(view, VIEW_BOTTOM_PADDING)) {
-                    view->bottom_padding = bottom_padding;
-                    view_update(view);
-                    view_flush(view);
-                }
-            }
-            bucket = bucket->next;
+    table_for (struct view *view, sm->view, {
+        if (!view_check_flag(view, VIEW_BOTTOM_PADDING)) {
+            view->bottom_padding = bottom_padding;
+            view_update(view);
+            view_flush(view);
         }
-    }
+    })
 }
 
 void space_manager_set_left_padding_for_all_spaces(struct space_manager *sm, int left_padding)
 {
     sm->left_padding = left_padding;
-    for (int i = 0; i < sm->view.capacity; ++i) {
-        struct bucket *bucket = sm->view.buckets[i];
-        while (bucket) {
-            if (bucket->value) {
-                struct view *view = bucket->value;
-                if (!view_check_flag(view, VIEW_LEFT_PADDING)) {
-                    view->left_padding = left_padding;
-                    view_update(view);
-                    view_flush(view);
-                }
-            }
-            bucket = bucket->next;
+    table_for (struct view *view, sm->view, {
+        if (!view_check_flag(view, VIEW_LEFT_PADDING)) {
+            view->left_padding = left_padding;
+            view_update(view);
+            view_flush(view);
         }
-    }
+    })
 }
 
 void space_manager_set_right_padding_for_all_spaces(struct space_manager *sm, int right_padding)
 {
     sm->right_padding = right_padding;
-    for (int i = 0; i < sm->view.capacity; ++i) {
-        struct bucket *bucket = sm->view.buckets[i];
-        while (bucket) {
-            if (bucket->value) {
-                struct view *view = bucket->value;
-                if (!view_check_flag(view, VIEW_RIGHT_PADDING)) {
-                    view->right_padding = right_padding;
-                    view_update(view);
-                    view_flush(view);
-                }
-            }
-            bucket = bucket->next;
+    table_for (struct view *view, sm->view, {
+        if (!view_check_flag(view, VIEW_RIGHT_PADDING)) {
+            view->right_padding = right_padding;
+            view_update(view);
+            view_flush(view);
         }
-    }
+    })
 }
 
 void space_manager_set_auto_balance_for_all_spaces(struct space_manager *sm, bool auto_balance)
 {
     sm->auto_balance = auto_balance;
-    for (int i = 0; i < sm->view.capacity; ++i) {
-        struct bucket *bucket = sm->view.buckets[i];
-        while (bucket) {
-            if (bucket->value) {
-                struct view *view = bucket->value;
-                if (!view_check_flag(view, VIEW_AUTO_BALANCE)) {
-                    view->auto_balance = auto_balance;
-                }
-            }
-            bucket = bucket->next;
+    table_for (struct view *view, sm->view, {
+        if (!view_check_flag(view, VIEW_AUTO_BALANCE)) {
+            view->auto_balance = auto_balance;
         }
-    }
+    })
 }
 
 bool space_manager_set_padding_for_space(struct space_manager *sm, uint64_t sid, int type, int top, int bottom, int left, int right)
@@ -694,16 +645,29 @@ uint64_t space_manager_active_space(void)
     return display_space_id(did);
 }
 
+void space_manager_move_window_list_to_space(uint64_t sid, uint32_t *window_list, int window_count)
+{
+    if (!workspace_use_macos_space_workaround()) {
+        CFArrayRef window_list_ref = cfarray_of_cfnumbers(window_list, sizeof(uint32_t), window_count, kCFNumberSInt32Type);
+        SLSMoveWindowsToManagedSpace(g_connection, window_list_ref, sid);
+        CFRelease(window_list_ref);
+    } else if (!scripting_addition_move_window_list_to_space(sid, window_list, window_count)) {
+        SLSSpaceSetCompatID(g_connection, sid, 0x79616265);
+        SLSSetWindowListWorkspace(g_connection, window_list, window_count, 0x79616265);
+        SLSSpaceSetCompatID(g_connection, sid, 0x0);
+    }
+}
+
 void space_manager_move_window_to_space(uint64_t sid, struct window *window)
 {
-    if (workspace_is_macos_sonoma14_5_or_newer()) {
-        SLSSpaceSetCompatID(g_connection, sid, 0x79616265);
-        SLSSetWindowListWorkspace(g_connection, &window->id, 1, 0x79616265);
-        SLSSpaceSetCompatID(g_connection, sid, 0x0);
-    } else {
+    if (!workspace_use_macos_space_workaround()) {
         CFArrayRef window_list_ref = cfarray_of_cfnumbers(&window->id, sizeof(uint32_t), 1, kCFNumberSInt32Type);
         SLSMoveWindowsToManagedSpace(g_connection, window_list_ref, sid);
         CFRelease(window_list_ref);
+    } else if (!scripting_addition_move_window_to_space(sid, window->id)) {
+        SLSSpaceSetCompatID(g_connection, sid, 0x79616265);
+        SLSSetWindowListWorkspace(g_connection, &window->id, 1, 0x79616265);
+        SLSSpaceSetCompatID(g_connection, sid, 0x0);
     }
 }
 
@@ -777,15 +741,11 @@ static enum space_op_error space_manager_swap_space_with_space_on_display(uint32
     table_add(&g_space_manager.view, &b_sid, a_view);
 
     if (a_window_list_count) {
-        CFArrayRef window_list_ref = cfarray_of_cfnumbers(a_window_list, sizeof(uint32_t), a_window_list_count, kCFNumberSInt32Type);
-        SLSMoveWindowsToManagedSpace(g_connection, window_list_ref, b_sid);
-        CFRelease(window_list_ref);
+        space_manager_move_window_list_to_space(b_sid, a_window_list, a_window_list_count);
     }
 
     if (b_window_list_count) {
-        CFArrayRef window_list_ref = cfarray_of_cfnumbers(b_window_list, sizeof(uint32_t), b_window_list_count, kCFNumberSInt32Type);
-        SLSMoveWindowsToManagedSpace(g_connection, window_list_ref, a_sid);
-        CFRelease(window_list_ref);
+        space_manager_move_window_list_to_space(a_sid, b_window_list, b_window_list_count);
     }
 
     for (int i = 0; i < buf_len(g_space_manager.labels); ++i) {
@@ -1106,18 +1066,11 @@ void space_manager_handle_display_add(struct space_manager *sm, uint32_t did)
     struct view *view_list[sm->view.count];
     CFStringRef uuid_list[sm->view.count];
 
-    for (int i = 0; i < sm->view.capacity; ++i) {
-        struct bucket *bucket = sm->view.buckets[i];
-        while (bucket) {
-            if (bucket->value) {
-                struct view *view = bucket->value;
-                view_list[list_count] = view;
-                uuid_list[list_count] = view->uuid;
-                ++list_count;
-            }
-            bucket = bucket->next;
-        }
-    }
+    table_for (struct view *view, sm->view, {
+        view_list[list_count] = view;
+        uuid_list[list_count] = view->uuid;
+        ++list_count;
+    })
 
     for (int i = 0; i < space_count; ++i) {
         uint64_t sid = space_list[i];
