@@ -51,7 +51,7 @@ struct view *space_manager_find_view(struct space_manager *sm, uint64_t sid);
 void space_manager_refresh_view(struct space_manager *sm, uint64_t sid);
 void space_manager_mark_view_invalid(struct space_manager *sm,  uint64_t sid);
 void space_manager_mark_view_dirty(struct space_manager *sm,  uint64_t sid);
-void space_manager_untile_window(struct space_manager *sm, struct view *view, struct window *window);
+void space_manager_untile_window(struct view *view, struct window *window);
 struct view *space_manager_tile_window_on_space_with_insertion_point(struct space_manager *sm, struct window *window, uint64_t sid, uint32_t insertion_point);
 struct view *space_manager_tile_window_on_space(struct space_manager *sm, struct window *window, uint64_t sid);
 bool space_manager_equalize_space(struct space_manager *sm, uint64_t sid, uint32_t axis_flag);
@@ -85,6 +85,7 @@ bool space_manager_set_padding_for_space(struct space_manager *sm, uint64_t sid,
 bool space_manager_toggle_padding_for_space(struct space_manager *sm, uint64_t sid);
 bool space_manager_rotate_space(struct space_manager *sm, uint64_t sid, int degrees);
 bool space_manager_mirror_space(struct space_manager *sm, uint64_t sid, enum window_node_split axis);
+void space_manager_move_window_list_to_space(uint64_t sid, uint32_t *window_list, int window_count);
 void space_manager_move_window_to_space(uint64_t sid, struct window *window);
 enum space_op_error space_manager_focus_space(uint64_t sid);
 enum space_op_error space_manager_switch_space(uint64_t sid);
