@@ -3,26 +3,6 @@ extern struct display_manager g_display_manager;
 extern struct space_manager g_space_manager;
 extern struct window_manager g_window_manager;
 
-void insert_feedback_update_notifications(void)
-{
-    int window_count = 0;
-    uint32_t window_list[1024] = {0};
-
-    for (int i = 0; i < g_window_manager.insert_feedback.capacity; ++i) {
-        struct bucket *bucket = g_window_manager.insert_feedback.buckets[i];
-        while (bucket) {
-            if (bucket->value) {
-                struct window_node *node = bucket->value;
-                window_list[window_count++] = node->window_order[0];
-            }
-
-            bucket = bucket->next;
-        }
-    }
-
-    SLSRequestNotificationsForWindows(g_connection, window_list, window_count);
-}
-
 #define INSERT_FEEDBACK_WIDTH 2
 #define INSERT_FEEDBACK_RADIUS 9
 void insert_feedback_show(struct window_node *node)
@@ -61,7 +41,9 @@ void insert_feedback_show(struct window_node *node)
         SLSReenableUpdate(g_connection);
         SLSOrderWindow(g_connection, node->feedback_window.id, 1, node->window_order[0]);
         table_add(&g_window_manager.insert_feedback, &node->window_order[0], node);
-        insert_feedback_update_notifications();
+        if (!workspace_is_macos_sequoia()) {
+            update_window_notifications();
+        }
     }
 
     CGFloat clip_x, clip_y, clip_w, clip_h;
@@ -124,7 +106,10 @@ void insert_feedback_destroy(struct window_node *node)
 {
     if (node->feedback_window.id) {
         table_remove(&g_window_manager.insert_feedback, &node->window_order[0]);
-        insert_feedback_update_notifications();
+
+        if (!workspace_is_macos_sequoia()) {
+            update_window_notifications();
+        }
 
         SLSOrderWindow(g_connection, node->feedback_window.id, 0, 0);
         CGContextRelease(node->feedback_window.context);
@@ -511,16 +496,13 @@ struct window_node *window_node_fence(struct window_node *node, int dir)
 {
     if (!node) return NULL;
 
-    struct window_node *parent = node->parent;
-    while (parent) {
-    if ((dir == DIR_NORTH && parent->split == SPLIT_X && parent->area.y < node->area.y) ||
-        (dir == DIR_WEST  && parent->split == SPLIT_Y && parent->area.x < node->area.x) ||
-        (dir == DIR_SOUTH && parent->split == SPLIT_X && (parent->area.y + parent->area.h) > (node->area.y + node->area.h)) ||
-        (dir == DIR_EAST  && parent->split == SPLIT_Y && (parent->area.x + parent->area.w) > (node->area.x + node->area.w))) {
-            return parent;
+    for (struct window_node *parent = node->parent; parent; parent = parent->parent) {
+        if ((dir == DIR_NORTH && parent->split == SPLIT_X && parent->area.y < node->area.y) ||
+            (dir == DIR_WEST  && parent->split == SPLIT_Y && parent->area.x < node->area.x) ||
+            (dir == DIR_SOUTH && parent->split == SPLIT_X && (parent->area.y + parent->area.h) > (node->area.y + node->area.h)) ||
+            (dir == DIR_EAST  && parent->split == SPLIT_Y && (parent->area.x + parent->area.w) > (node->area.x + node->area.w))) {
+                return parent;
         }
-
-        parent = parent->parent;
     }
 
     return NULL;
@@ -595,9 +577,8 @@ struct window_node *view_find_window_node_in_direction(struct view *view, struct
     struct window_node *best_node = NULL;
     CGPoint source_area_max = area_max_point(source->area);
 
-    struct window_node *target = window_node_find_first_leaf(view->root);
-    while (target) {
-        if (source == target) goto next;
+    for (struct window_node *target = window_node_find_first_leaf(view->root); target; target = window_node_find_next_leaf(target)) {
+        if (source == target) continue;
 
         CGPoint target_area_max = area_max_point(target->area);
         if (area_is_in_direction(&source->area, source_area_max, &target->area, target_area_max, direction)) {
@@ -609,9 +590,6 @@ struct window_node *view_find_window_node_in_direction(struct view *view, struct
                 best_rank = rank;
             }
         }
-
-next:
-        target = window_node_find_next_leaf(target);
     }
 
     return best_node;
@@ -619,10 +597,8 @@ next:
 
 struct window_node *view_find_window_node(struct view *view, uint32_t window_id)
 {
-    struct window_node *node = window_node_find_first_leaf(view->root);
-    while (node) {
+    for (struct window_node *node = window_node_find_first_leaf(view->root); node; node = window_node_find_next_leaf(node)) {
         if (window_node_contains_window(node, window_id)) return node;
-        node = window_node_find_next_leaf(node);
     }
 
     return NULL;
@@ -737,9 +713,22 @@ struct window_node *view_remove_window_node(struct view *view, struct window *wi
     return parent;
 }
 
-void view_stack_window_node(struct view *view, struct window_node *node, struct window *window)
+void view_stack_window_node(struct window_node *node, struct window *window)
 {
-    node->window_list[node->window_count]  = window->id;
+    int insert_index = node->window_count;
+
+    for (int i = 0; i < node->window_count; ++i) {
+        if (node->window_list[i] == node->window_order[0]) {
+            insert_index = i+1;
+            break;
+        }
+    }
+
+    if (insert_index < node->window_count) {
+        memmove(node->window_list + insert_index + 1, node->window_list + insert_index, sizeof(uint32_t) * (node->window_count - insert_index));
+    }
+
+    node->window_list[insert_index] = window->id;
     memmove(node->window_order + 1, node->window_order, sizeof(uint32_t) * node->window_count);
     node->window_order[0] = window->id;
     ++node->window_count;
@@ -773,7 +762,7 @@ struct window_node *view_add_window_node_with_insertion_point(struct view *view,
                 insert_feedback_destroy(leaf);
 
                 if (do_stack) {
-                    view_stack_window_node(view, leaf, window);
+                    view_stack_window_node(leaf, window);
                     return leaf;
                 }
             }
@@ -792,7 +781,7 @@ struct window_node *view_add_window_node_with_insertion_point(struct view *view,
 
         return leaf;
     } else if (view->layout == VIEW_STACK) {
-        view_stack_window_node(view, view->root, window);
+        view_stack_window_node(view->root, window);
         return view->root;
     }
 
@@ -811,8 +800,7 @@ uint32_t *view_find_window_list(struct view *view, int *window_count)
     int capacity = 13;
     uint32_t *window_list = ts_alloc_list(uint32_t, capacity);
 
-    struct window_node *node = window_node_find_first_leaf(view->root);
-    while (node) {
+    for (struct window_node *node = window_node_find_first_leaf(view->root); node; node = window_node_find_next_leaf(node)) {
         if (*window_count + node->window_count >= capacity) {
             ts_expand(window_list, sizeof(uint32_t) * capacity, sizeof(uint32_t) * capacity);
             capacity *= 2;
@@ -821,8 +809,6 @@ uint32_t *view_find_window_list(struct view *view, int *window_count)
         for (int i = 0; i < node->window_count; ++i) {
             window_list[(*window_count)++] = node->window_list[i];
         }
-
-        node = window_node_find_next_leaf(node);
     }
 
     return window_list;
@@ -959,7 +945,7 @@ void view_serialize(FILE *rsp, struct view *view, uint64_t flags)
 void view_update(struct view *view)
 {
     uint32_t did = space_display_id(view->sid);
-    CGRect frame = display_bounds_constrained(did);
+    CGRect frame = display_bounds_constrained(did, false);
     view->root->area = area_from_cgrect(frame);
 
     if (view_check_flag(view, VIEW_ENABLE_PADDING)) {
