@@ -734,7 +734,7 @@ char *window_title_ts(struct window *window)
 
 CGPoint window_ax_origin(struct window *window)
 {
-    CGPoint origin = {};
+    CGPoint origin = {0};
     CFTypeRef position_ref = NULL;
 
     AXUIElementCopyAttributeValue(window->ref, kAXPositionAttribute, &position_ref);
@@ -749,7 +749,7 @@ CGPoint window_ax_origin(struct window *window)
 
 CGRect window_ax_frame(struct window *window)
 {
-    CGRect frame = {};
+    CGRect frame = {0};
     CFTypeRef position_ref = NULL;
     CFTypeRef size_ref = NULL;
 
@@ -889,7 +889,7 @@ int window_level(uint32_t wid)
 {
     int level = 0;
 
-    if (workspace_is_macos_ventura() || workspace_is_macos_sonoma()) {
+    if (workspace_is_macos_ventura() || workspace_is_macos_sonoma() || workspace_is_macos_sequoia()) {
         CFArrayRef window_ref = cfarray_of_cfnumbers(&wid, sizeof(uint32_t), 1, kCFNumberSInt32Type);
 
         CFTypeRef query = SLSWindowQueryWindows(g_connection, window_ref, 1);
