@@ -22,7 +22,7 @@
 
 #define MAJOR  7
 #define MINOR  1
-#define PATCH  1
+#define PATCH  4
 
 struct signal *g_signal_event[SIGNAL_TYPE_COUNT];
 struct process_manager g_process_manager;
@@ -307,10 +307,15 @@ int main(int argc, char **argv)
         error("yabai: could not start mouse handler! abort..\n");
     }
 
-    if (workspace_is_macos_monterey() || workspace_is_macos_ventura() || workspace_is_macos_sonoma()) {
+    if (workspace_is_macos_monterey() ||
+        workspace_is_macos_ventura() ||
+        workspace_is_macos_sonoma() ||
+        workspace_is_macos_sequoia()) {
         mission_control_observe();
 
-        if (workspace_is_macos_ventura() || workspace_is_macos_sonoma()) {
+        if (workspace_is_macos_ventura() ||
+            workspace_is_macos_sonoma() ||
+            workspace_is_macos_sequoia()) {
             SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 1327, NULL);
             SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 1328, NULL);
         }
@@ -320,10 +325,18 @@ int main(int argc, char **argv)
 
     SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 808, NULL);
 
+    if (workspace_is_macos_sequoia()) {
+        SLSRegisterConnectionNotifyProc(g_connection, connection_handler, 804, NULL);
+    }
+
     window_manager_init(&g_window_manager);
     space_manager_begin(&g_space_manager);
     window_manager_begin(&g_space_manager, &g_window_manager);
 
+    if (workspace_is_macos_sequoia()) {
+        update_window_notifications();
+    }
+
     if (!message_loop_begin(g_socket_file)) {
         error("yabai: could not start message loop! abort..\n");
     }
@@ -342,4 +355,4 @@ int main(int argc, char **argv)
 }
 #endif
 
-PROFILER_END_TRANSLATION_UNIT;
+PROFILER_END_TRANSLATION_UNIT
